"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TemporalNodejsWorkerImage = void 0;
const constructs_1 = require("constructs");
const aws_cdk_lib_1 = require("aws-cdk-lib");
const aws_ecr_assets_1 = require("aws-cdk-lib/aws-ecr-assets");
const child_process_1 = require("child_process");
const path_1 = __importDefault(require("path"));
class TemporalNodejsWorkerImage extends constructs_1.Construct {
    constructor(scope, id, props) {
        super(scope, id);
        const staging = new aws_cdk_lib_1.AssetStaging(this, 'Staging', {
            sourcePath: path_1.default.dirname(props.entrypoint),
            assetHashType: aws_cdk_lib_1.AssetHashType.OUTPUT,
            extraHash: `${Math.random()}`,
            bundling: {
                local: {
                    tryBundle: (outputDir) => {
                        // Staging directory containing files of the worker bundle
                        const nodeJsCmd = process.execPath;
                        const nodeJsArgs = process.execArgv; // FIXME: Remove `-e ...` or `--eval ...` sequences to prevent fork bomb
                        const prepareWorkerDockerDirCmd = require.resolve('./nodejsWorkerBundling/prepareWorkerDocker');
                        const args = [
                            `${props.entrypoint}`,
                            outputDir,
                            ...(props.externals ?? []).map(encodeStringOrRegExp),
                        ];
                        (0, child_process_1.spawnSync)(nodeJsCmd, [...nodeJsArgs, prepareWorkerDockerDirCmd, ...args], {
                            stdio: [
                                'ignore',
                                process.stderr,
                                'inherit', // inherit stderr
                            ],
                        });
                        return true;
                    },
                },
                image: aws_cdk_lib_1.DockerImage.fromRegistry('dummy'),
            },
        });
        this.dockerImageAsset = new aws_ecr_assets_1.DockerImageAsset(this, 'ImageAsset', {
            directory: staging.absoluteStagedPath,
            buildArgs: {
                BUILD_IMAGE: `node:16-bullseye-slim`,
                RUNTIME_IMAGE: `gcr.io/distroless/nodejs:16`,
            },
        });
    }
}
exports.TemporalNodejsWorkerImage = TemporalNodejsWorkerImage;
function encodeStringOrRegExp(x) {
    if (typeof x === 'string')
        return x;
    if (x instanceof RegExp)
        return `/${x.source}/${x.flags.includes('i') ? 'i' : ''}`;
    throw new Error('Expected argument to be either a string or a RegExp');
}
//# sourceMappingURL=TemporalNodejsWorkerImage.js.map