import { Secret } from 'aws-cdk-lib/aws-ecs';
import { TemporalDatabase } from '../customResources/temporal/TemporalDatabaseResource';
export declare class TemporalConfiguration {
    configuration: {
        log: {
            stdout: boolean;
            level: string;
        };
        persistence: {
            numHistoryShards: number;
            defaultStore: string;
            visibilityStore: string;
            datastores: {
                default: IMySQLConnectionConfig | IPostgresqlConnectionConfig;
                visibility: IMySQLConnectionConfig | IPostgresqlConnectionConfig;
            };
        };
        global: {
            membership: {
                name: string;
                maxJoinDuration: string;
                broadcastAddress: {};
            };
            pprof: {
                port: number;
            };
        };
        services: {
            frontend: {
                rpc: {
                    grpcPort: number;
                    membershipPort: number;
                    bindOnIP: string;
                };
                metrics: {
                    tags: {
                        type: string;
                    };
                    prometheus: {
                        timerType: string;
                        listenAddress: string;
                    };
                };
            };
            history: {
                rpc: {
                    grpcPort: number;
                    membershipPort: number;
                    bindOnIP: string;
                };
                metrics: {
                    tags: {
                        type: string;
                    };
                    prometheus: {
                        timerType: string;
                        listenAddress: string;
                    };
                };
            };
            matching: {
                rpc: {
                    grpcPort: number;
                    membershipPort: number;
                    bindOnIP: string;
                };
                metrics: {
                    tags: {
                        type: string;
                    };
                    prometheus: {
                        timerType: string;
                        listenAddress: string;
                    };
                };
            };
            worker: {
                rpc: {
                    grpcPort: number;
                    membershipPort: number;
                    bindOnIP: string;
                };
                metrics: {
                    tags: {
                        type: string;
                    };
                    prometheus: {
                        timerType: string;
                        listenAddress: string;
                    };
                };
            };
        };
        clusterMetadata: {
            enableGlobalDomain: boolean;
            failoverVersionIncrement: number;
            masterClusterName: string;
            currentClusterName: string;
            clusterInformation: {
                active: {
                    enabled: boolean;
                    initialFailoverVersion: number;
                    rpcName: string;
                    rpcAddress: string;
                };
            };
        };
        dcRedirectionPolicy: {
            policy: string;
            toDC: string;
        };
        archival: {
            status: string;
        };
        publicClient: {
            hostPort: string;
        };
        dynamicConfigClient: {
            filepath: string;
            pollInterval: string;
        };
    };
    dynamic: {};
    web: {
        auth: {
            enabled: boolean;
        };
        routing: {
            issue_report_link: string;
        };
    };
    private envVariables;
    private secrets;
    toEnvironmentVariables(): {
        [k: string]: string;
    };
    toSecrets(): {
        [key: string]: Secret;
    };
    stringifyConfiguration(): string;
    stringifyDynamic(): string;
    stringifyWeb(): string;
    attachDatabase(database: TemporalDatabase): void;
}
interface IMySQLConnectionConfig {
    sql: {
        pluginName: 'mysql';
        driverName: 'mysql';
        databaseName: string;
        connectAddr: string;
        connectProtocol: 'tcp';
        user: string;
        password: string;
        maxConnLifetime: string;
        maxConns: number;
        secretName: string;
    };
}
interface IPostgresqlConnectionConfig {
    sql: {
        pluginName: 'postgres';
        driverName: 'postgres';
        databaseName: string;
        connectAddr: string;
        connectProtocol: 'tcp';
        user: string;
        password: string;
        maxConnLifetime: string;
        maxConns: number;
        secretName: string;
    };
}
export {};
