"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteObject = exports.putObject = exports.onEvent = void 0;
const path_1 = require("path");
const fs_1 = require("fs");
async function onEvent(event) {
    switch (event.RequestType) {
        case 'Create':
        case 'Update':
            return putObject(event);
        case 'Delete':
            return deleteObject(event);
    }
}
exports.onEvent = onEvent;
async function putObject(event) {
    const properties = event.ResourceProperties;
    if (!properties.FileSystemId)
        throw new Error('"FileSystemId" is required');
    if (!properties.Contents)
        throw new Error('"Contents" is required');
    if (!properties.Path)
        throw new Error('"Path" is required');
    // FIXME: Not sure about encoding...
    console.log(`Writing to file efs://${properties.FileSystemId}/${properties.Path}`);
    (0, fs_1.mkdirSync)((0, path_1.dirname)(toLocalPath(properties.Path)), { recursive: true });
    (0, fs_1.writeFileSync)(toLocalPath(properties.Path), properties.Contents, { encoding: 'utf-8' });
    return {
        PhysicalResourceId: `efs://${properties.FileSystemId}/${properties.Path}`,
    };
}
exports.putObject = putObject;
async function deleteObject(event) {
    const properties = event.ResourceProperties;
    if (!properties.FileSystemId)
        throw new Error('"FileSystemId" is required');
    if (!properties.Contents)
        throw new Error('"Contents" is required');
    if (!properties.Path)
        throw new Error('"Path" is required');
    console.log(`Deleting file efs://${properties.FileSystemId}/${properties.Path}`);
    (0, fs_1.rmSync)(toLocalPath(properties.Path), { force: true });
    return {
        PhysicalResourceId: `efs://${properties.FileSystemId}/${properties.Path}`,
    };
}
exports.deleteObject = deleteObject;
function toLocalPath(path) {
    return (0, path_1.join)('/mnt', path);
}
//# sourceMappingURL=EfsFileHandler.js.map