"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EfsFileProvider = void 0;
const constructs_1 = require("constructs");
const lambda = __importStar(require("aws-cdk-lib/aws-lambda"));
const aws_cdk_lib_1 = require("aws-cdk-lib");
const custom_resources_1 = require("aws-cdk-lib/custom-resources");
const aws_lambda_nodejs_1 = require("aws-cdk-lib/aws-lambda-nodejs");
const aws_logs_1 = require("aws-cdk-lib/aws-logs");
class EfsFileProvider extends constructs_1.Construct {
    constructor(scope, id, props) {
        super(scope, id);
        this.node.addDependency(props.vpc);
        // https://github.com/aws/aws-cdk/blob/621a410471fcda0e388a7a53bb0e3cdb77be759c/packages/%40aws-cdk/aws-s3-deployment/lib/bucket-deployment.ts#L260
        const accessPoint = props.fileSystem.addAccessPoint('AccessPoint', {
            path: props.rootDir,
            createAcl: {
                ownerUid: '1001',
                ownerGid: '1001',
                permissions: '0777',
            },
            posixUser: {
                uid: '1001',
                gid: '1001',
            },
        });
        const lambdaFunction = new aws_lambda_nodejs_1.NodejsFunction(this, 'OnEventHandler', {
            entry: require.resolve('./EfsFileHandler'),
            runtime: lambda.Runtime.NODEJS_14_X,
            handler: 'onEvent',
            vpc: props.vpc,
            vpcSubnets: props.vpcSubnets,
            filesystem: lambda.FileSystem.fromEfsAccessPoint(accessPoint, `/mnt${props.rootDir}`),
        });
        this.provider = new custom_resources_1.Provider(this, 'Provider', {
            onEventHandler: lambdaFunction,
            logRetention: aws_logs_1.RetentionDays.FIVE_DAYS,
        });
    }
    /**
     * Returns the singleton provider corresponding to the given vpc and file system.
     */
    static getOrCreate(scope, props) {
        const id = `CustomResource-EfsFileProvider-${props.vpc.node.addr}-${props.fileSystem.node.addr}-${props.rootDir.slice(1)}`;
        const stack = aws_cdk_lib_1.Stack.of(scope);
        const x = stack.node.tryFindChild(id) || new EfsFileProvider(stack, id, props);
        return x.provider.serviceToken;
    }
}
exports.EfsFileProvider = EfsFileProvider;
//# sourceMappingURL=EfsFileProvider.js.map