"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EfsFile = void 0;
const constructs_1 = require("constructs");
const aws_cdk_lib_1 = require("aws-cdk-lib");
const path_1 = require("path");
const EfsFileProvider_1 = require("./EfsFileProvider");
class EfsFile extends constructs_1.Construct {
    constructor(scope, id, props) {
        super(scope, id);
        const normalizedPath = path_1.posix.normalize(props.path);
        const [, rootDir] = normalizedPath.match(/^([/][^/]+)[/].*[^/]$/);
        if (!rootDir)
            throw new Error('Path must be absolute, must point to a file, and must have at least one intermediate directory');
        // Making the VPC dependent on EfsFile is required to avoid potential CFN stack deletion
        // issues. Refer to https://github.com/aws/aws-cdk/pull/15220 for explanations.
        this.node.addDependency(props.vpc);
        new aws_cdk_lib_1.CustomResource(this, 'Resource', {
            serviceToken: EfsFileProvider_1.EfsFileProvider.getOrCreate(this, {
                vpc: props.vpc,
                vpcSubnets: props.vpcSubnets,
                fileSystem: props.fileSystem,
                rootDir: rootDir,
            }),
            resourceType: 'Custom::EfsFile',
            properties: {
                FileSystemId: props.fileSystem.fileSystemId,
                Contents: props.contents,
                Path: props.path,
            },
        });
        // FIXME: Determine if there is a need for any output attribute
    }
}
exports.EfsFile = EfsFile;
//# sourceMappingURL=EfsFileResource.js.map