"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TemporalDatabaseProvider = void 0;
const aws_cdk_lib_1 = require("aws-cdk-lib");
const aws_lambda_1 = require("aws-cdk-lib/aws-lambda");
const aws_lambda_nodejs_1 = require("aws-cdk-lib/aws-lambda-nodejs");
const aws_logs_1 = require("aws-cdk-lib/aws-logs");
const custom_resources_1 = require("aws-cdk-lib/custom-resources");
const constructs_1 = require("constructs");
const AdminToolsLayer_1 = require("./AdminToolsLayer");
class TemporalDatabaseProvider extends constructs_1.Construct {
    constructor(cluster, id) {
        super(cluster, id);
        this.node.addDependency(cluster.ecsCluster.vpc);
        this.lambdaFunction = new aws_lambda_nodejs_1.NodejsFunction(this, 'OnEventHandler', {
            entry: require.resolve('./TemporalDatabaseHandler'),
            runtime: aws_lambda_1.Runtime.NODEJS_14_X,
            handler: 'onEvent',
            vpc: cluster.ecsCluster.vpc,
            layers: [AdminToolsLayer_1.AdminToolsLayer.getOrCreate(this, cluster.temporalVersion)],
            timeout: aws_cdk_lib_1.Duration.minutes(5),
        });
        this.provider = new custom_resources_1.Provider(this, 'Provider', {
            onEventHandler: this.lambdaFunction,
            logRetention: aws_logs_1.RetentionDays.ONE_DAY,
        });
    }
    /**
     * We create a single instance of this provider by Temporal cluster.
     * Privileges for that single instance's lambda function are then expanded
     * to include network access and secret access for each datastore.
     */
    static getOrCreate(cluster, datastore) {
        const id = 'CustomResource-TemporalDatabaseProvider';
        const provider = cluster.node.tryFindChild(id) ?? new TemporalDatabaseProvider(cluster, id);
        provider.expandPrivilegesToDatastore(datastore);
        return provider.provider.serviceToken;
    }
    expandPrivilegesToDatastore(datastore) {
        this.lambdaFunction.connections.allowToDefaultPort(datastore);
        datastore.secret.grantRead(this.lambdaFunction);
    }
}
exports.TemporalDatabaseProvider = TemporalDatabaseProvider;
//# sourceMappingURL=TemporalDatabaseProvider.js.map