"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TemporalDatabase = void 0;
const aws_cdk_lib_1 = require("aws-cdk-lib");
const constructs_1 = require("constructs");
const TemporalDatabaseProvider_1 = require("./TemporalDatabaseProvider");
// Represents a Temporal schema
class TemporalDatabase extends constructs_1.Construct {
    constructor(cluster, id, props) {
        super(cluster, id);
        const provider = TemporalDatabaseProvider_1.TemporalDatabaseProvider.getOrCreate(cluster, props.datastore);
        new aws_cdk_lib_1.CustomResource(this, 'Resource', {
            serviceToken: provider,
            resourceType: 'Custom::TemporalSchema',
            properties: {
                DatastorePlugin: props.datastore.plugin,
                DatastoreHost: props.datastore.host,
                DatastorePort: aws_cdk_lib_1.Token.asString(props.datastore.port),
                DatastoreSecretId: props.datastore.secret.secretName,
                SchemaType: props.schemaType,
                DatabaseName: props.databaseName,
                TemporalVersion: cluster.temporalVersion.version,
            },
            removalPolicy: props.removalPolicy ?? aws_cdk_lib_1.RemovalPolicy.RETAIN,
        });
        this.datastore = props.datastore;
        this.databaseName = props.databaseName;
        this.schemaType = props.schemaType;
    }
}
exports.TemporalDatabase = TemporalDatabase;
//# sourceMappingURL=TemporalDatabaseResource.js.map