"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.NodejsWorkerBundler = void 0;
const util_1 = __importDefault(require("util"));
const webpack_1 = __importDefault(require("webpack"));
const realFS = __importStar(require("fs"));
const worker_1 = require("@temporalio/worker");
const babelPlugin_1 = require("./babelPlugin");
const path_1 = __importDefault(require("path"));
// FIXME: Evaluate the pertinance of contributing this file to @temporalio/worker once fully validated
class NodejsWorkerBundler {
    constructor(opts) {
        this.externalDepsPatterns = [];
        this.workflowsBundles = {};
        this.packageJson = {
            dependencies: {},
            private: true,
        };
        this.optimize = true;
        if (!path_1.default.isAbsolute(opts.entrypointPath))
            throw new Error(`entrypointPath must be absolute`);
        this.entrypointPath = opts.entrypointPath;
        this.entrypointPackageRoot = findPackageRoot(this.entrypointPath);
        this.targetPath = opts.targetPath;
        this.packageJson.main = path_1.default.basename(this.entrypointPath);
        this.externalDepsPatterns = [
            // Externalize workflows bundles generated by this class, as they have not yet been created
            /^.[/](?:[a-z0-9-]+)[.]workflowbundle[.]js$/,
            // @temporalio/core-bridge package contains native code. proto and commons are dependencies
            // of core-bridge; there is therefore no use in inlining them in the bundle.
            /^@temporalio[/]core-bridge$/,
            /^@temporalio[/]proto$/,
            /^@temporalio[/]common$/,
            ...(opts.externals ?? []).map(toRegExp),
        ];
    }
    async bundle() {
        await this.bundleWorker(this.entrypointPath, this.targetPath);
        await this.bundleWorkflows(path_1.default.dirname(this.targetPath));
        await this.generatePackageJson(path_1.default.dirname(this.targetPath));
    }
    async bundleWorker(entry, target) {
        const workflowsTransform = (workflowsPath, { filename }) => {
            if (!(workflowsPath.startsWith('./') || workflowsPath.startsWith('../')))
                throw new Error('workflowsPath must be relative');
            const sourcePath = path_1.default.resolve(path_1.default.dirname(filename), workflowsPath);
            const baseWorkflowsBundleId = path_1.default
                .basename(workflowsPath)
                .replace(/[^a-z0-9]+/i, '-')
                .replace(/^-/, '')
                .replace(/-$/, '');
            // Check and resolve collision with distinct workflows bundle that could happens to have the same ID
            let workflowsBundleId = baseWorkflowsBundleId;
            let suffix = 1;
            while (workflowsBundleId in this.workflowsBundles &&
                this.workflowsBundles[workflowsBundleId].sourcePath !== sourcePath) {
                workflowsBundleId = `${baseWorkflowsBundleId}-${suffix++}`;
            }
            const targetPath = `./${workflowsBundleId}.workflowbundle.js`;
            this.workflowsBundles[workflowsBundleId] = { sourcePath, targetPath };
            return targetPath;
        };
        const extractDependencies = async (data, _callback) => {
            try {
                const resolvedPath = (await data.getResolve()(data.context, data.request, undefined));
                const packageRoot = findPackageRoot(resolvedPath);
                if (packageRoot && packageRoot !== this.entrypointPackageRoot) {
                    const { name: packageName, version: packageVersion } = require(`${packageRoot}/package.json`); // eslint-disable-line @typescript-eslint/no-var-requires
                    if (this.externalDepsPatterns.some((pattern) => pattern.test(packageName))) {
                        this.packageJson.dependencies[packageName] = `${packageVersion}`;
                        return `commonjs ${data.request}`;
                    }
                    return undefined;
                }
            }
            catch (_e) {
                /* Fallback to default logic below */
            }
            if (this.externalDepsPatterns.some((pattern) => pattern.test(data.request))) {
                if (!/^[.][.]?[/]/.test(data.request)) {
                    // Report a warning if the requested file is not relative
                    console.log(`Warning: Failed to locate package.json for dependency ${data.request}.\n` +
                        `That dependency WILL NOT be added to the generated worker's package.json.\n` +
                        `This could possibly cause missing dependencies at runtime.`);
                }
                return `commonjs ${data.request}`;
            }
            return undefined;
        };
        const webpackConfig = {
            resolve: {
                extensions: ['.ts', '.js'],
                alias: {
                    ...(this.optimize ? { webpack: false } : {}),
                },
            },
            target: 'node14.18',
            module: {
                rules: [
                    {
                        test: /\.js|\.ts$/,
                        exclude: /node_modules/,
                        use: [
                            {
                                loader: 'babel-loader',
                                options: {
                                    plugins: [[babelPlugin_1.temporalWorkflowsBundlingBabelPlugin, { workflowsTransform }]],
                                },
                            },
                            {
                                loader: 'ts-loader',
                                options: {
                                    compilerOptions: {
                                        // Retain import statements so that they can be easily analyzed by the babel plugin
                                        module: 'es2020',
                                    },
                                },
                            },
                        ],
                    },
                ],
            },
            entry: [entry],
            mode: 'development',
            devtool: 'eval-source-map',
            output: {
                path: path_1.default.dirname(target),
                filename: path_1.default.basename(target),
            },
            externals: extractDependencies,
        };
        const compiler = (0, webpack_1.default)(webpackConfig);
        try {
            await new Promise((resolve, reject) => {
                compiler.run((err, stats) => {
                    if (stats !== undefined) {
                        const hasError = stats.hasErrors();
                        const lines = stats.toString({ chunks: false, colors: true }).split('\n');
                        for (const line of lines) {
                            console[hasError ? 'error' : 'info'](line);
                        }
                        if (hasError) {
                            reject(new Error('Webpack finished with errors.'));
                        }
                    }
                    if (err) {
                        reject(err);
                    }
                    else {
                        resolve();
                    }
                });
            });
        }
        finally {
            await util_1.default.promisify(compiler.close).bind(compiler)();
        }
    }
    async bundleWorkflows(targetDirectory) {
        for (const bundleDefinition of Object.values(this.workflowsBundles)) {
            console.log(``);
            console.log(`Preparing workflows bundle from directory: ${bundleDefinition.sourcePath}`);
            const { code } = await (0, worker_1.bundleWorkflowCode)({
                workflowsPath: bundleDefinition.sourcePath,
                // FIXME: Capture workflowInterceptorModules on Worker.create()
                // workflowInterceptorModules: bundleDefinition.workflowInterceptorModules,
            });
            const targetFile = path_1.default.resolve(targetDirectory, bundleDefinition.targetPath);
            realFS.writeFileSync(targetFile, code, { encoding: 'utf-8' });
        }
        return;
    }
    async generatePackageJson(targetDirectory) {
        realFS.writeFileSync(`${targetDirectory}/package.json`, JSON.stringify(this.packageJson, null, 4), {
            encoding: 'utf-8',
        });
        return;
    }
}
exports.NodejsWorkerBundler = NodejsWorkerBundler;
function toRegExp(input) {
    if (input instanceof RegExp)
        return input;
    if (typeof input === 'string')
        return new RegExp(`^${input.replace('[.?*+|\\([{^$]', '\\$&')}$`);
    throw new Error('Unsupported input type');
}
function findPackageRoot(p) {
    if (realFS.statSync(p).isFile())
        p = path_1.default.dirname(p);
    while (p !== '/') {
        if (realFS.existsSync(`${p}/package.json`))
            return p;
        p = path_1.default.dirname(p);
    }
    return null;
}
//# sourceMappingURL=NodejsWorkerBundler.js.map