#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.prepareNodejsWorkerDocker = void 0;
const NodejsWorkerBundler_1 = require("./NodejsWorkerBundler");
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const process_1 = require("process");
const nopt_1 = __importDefault(require("nopt"));
async function prepareNodejsWorkerDocker(options) {
    fs_1.default.mkdirSync(path_1.default.dirname(options.targetPath), { recursive: true });
    const tmpTargetPath = fs_1.default.mkdtempSync(options.targetPath);
    try {
        await new NodejsWorkerBundler_1.NodejsWorkerBundler({
            entrypointPath: options.entrypointPath,
            targetPath: `${tmpTargetPath}/main.js`,
            externals: options.externals,
        }).bundle();
        fs_1.default.copyFileSync(`${__dirname}/Dockerfile`, `${tmpTargetPath}/Dockerfile`);
        fs_1.default.rmSync(options.targetPath, { recursive: true, force: true });
        fs_1.default.renameSync(tmpTargetPath, options.targetPath);
    }
    finally {
        try {
            fs_1.default.rmSync(tmpTargetPath, { recursive: true, force: true });
        }
        catch {
            // Ignore cleaning up errors as it would shadow the initial error, if any
        }
    }
}
exports.prepareNodejsWorkerDocker = prepareNodejsWorkerDocker;
function parseCli() {
    const knownOpts = {
        external: [String, Array],
    };
    const parsedOpts = (0, nopt_1.default)(knownOpts);
    if (parsedOpts.argv.remain.length !== 2) {
        console.error(`Error: expected exactly 2 arguments`);
        process.exit(1);
    }
    const entrypointPath = path_1.default.resolve(process.cwd(), parsedOpts.argv.remain[0]);
    const targetPath = path_1.default.resolve(process.cwd(), parsedOpts.argv.remain[1]);
    const externalsRaw = parsedOpts['external'] ?? [];
    const externals = externalsRaw.map(toStringOrRegExp);
    if (!isExistingFile(entrypointPath)) {
        console.error(`Error: no such file: '${entrypointPath}'`);
        process.exit(1);
    }
    return {
        entrypointPath,
        targetPath,
        externals,
    };
}
function toStringOrRegExp(s) {
    const matches = s.match(/^[/](.+)[/](i?)$/);
    if (matches)
        return new RegExp(matches[1], matches[2]);
    else
        return s;
}
function isExistingFile(file) {
    try {
        return fs_1.default.statSync(file).isFile();
    }
    catch {
        return false;
    }
}
prepareNodejsWorkerDocker(parseCli())
    .then(() => {
    console.log(`Done preparing Temporal worker's Docker directory`);
    (0, process_1.exit)(0);
})
    .catch((e) => {
    console.error(`Failed to prepare Temporal worker's Docker directory`);
    console.error(e);
    (0, process_1.exit)(1);
});
//# sourceMappingURL=prepareWorkerDocker.js.map