"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseTemporalService = void 0;
const aws_ecs_1 = require("aws-cdk-lib/aws-ecs");
const aws_logs_1 = require("aws-cdk-lib/aws-logs");
const constructs_1 = require("constructs");
const lodash_1 = require("lodash");
const aws_cdk_lib_1 = require("aws-cdk-lib");
const aws_ec2_1 = require("aws-cdk-lib/aws-ec2");
class BaseTemporalService extends constructs_1.Construct {
    constructor(cluster, id, props) {
        super(cluster, id);
        this.cluster = cluster;
        const taskDefinition = new aws_ecs_1.FargateTaskDefinition(this, `TaskDef`, {
            cpu: props.machine.cpu,
            memoryLimitMiB: props.machine.memoryLimitMiB,
            runtimePlatform: {
                cpuArchitecture: props.machine.cpuArchitecture,
                operatingSystemFamily: aws_ecs_1.OperatingSystemFamily.LINUX,
            },
            volumes: props.volumes.map((vol) => ({
                name: vol.name,
                efsVolumeConfiguration: {
                    fileSystemId: vol.fileSystem.fileSystemId,
                    rootDirectory: vol.volumePath,
                    // FIXME: Add authorization and in transit encryption
                },
            })),
        });
        const container = taskDefinition.addContainer(`Container`, {
            containerName: `${cluster.name}-${id}`,
            image: aws_ecs_1.ContainerImage.fromRegistry(props.image.image),
            environment: props.environement,
            secrets: props.secrets,
            logging: new aws_ecs_1.AwsLogDriver({
                streamPrefix: `${this.cluster.name}-${id}`,
                logGroup: new aws_logs_1.LogGroup(this, `LogGroup`, {
                    // FIXME: Make this configurable
                    removalPolicy: aws_cdk_lib_1.RemovalPolicy.RETAIN,
                    retention: aws_logs_1.RetentionDays.ONE_WEEK,
                }),
            }),
            portMappings: props.exposedPorts.map((port) => ({
                containerPort: port,
                hostPort: port,
                protocol: aws_ecs_1.Protocol.TCP,
            })),
        });
        container.addMountPoints(...props.volumes.map((vol) => ({
            sourceVolume: vol.name,
            containerPath: vol.containerPath,
            readOnly: vol.readOnly,
        })));
        this.fargateService = new aws_ecs_1.FargateService(this, `FargateService`, {
            cluster: cluster.ecsCluster,
            assignPublicIp: false,
            taskDefinition,
            // FIXME: Make this configurable
            vpcSubnets: { onePerAz: true, subnetType: aws_ec2_1.SubnetType.PRIVATE_WITH_NAT },
            platformVersion: aws_ecs_1.FargatePlatformVersion.VERSION1_4,
        });
        // Grant network access from the fargate service to the EFS file system
        for (const fs of (0, lodash_1.uniq)((0, lodash_1.map)(props.volumes, 'fileSystem'))) {
            fs.connections.allowDefaultPortFrom(this.fargateService);
        }
    }
    get connections() {
        return this.fargateService.connections;
    }
}
exports.BaseTemporalService = BaseTemporalService;
//# sourceMappingURL=BaseService.js.map